/*
 * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file net.h exported symbols from net.c */

/**
 * the buffer size of the sun_path component of struct sockaddr_un
 *
 * While glibc doesn't define \p UNIX_PATH_MAX, it
 * documents it has being limited to 108 bytes.
 */
#ifndef UNIX_PATH_MAX
#define UNIX_PATH_MAX 108
#endif

/** \cond Userland defines for Linux DCCP support. */
#ifndef IPPROTO_DCCP
#define IPPROTO_DCCP	33	/**< IANA assigned value */
#define SOCK_DCCP	6	/**< Linux socket type	 */
#define SOL_DCCP        269	/**< Linux socket level	 */
#endif
/** \endcond */

/**
 * Generic socket creation (passive and active sockets).
 */
extern int makesock(unsigned l3type, unsigned l4type, int passive,
	            const char *host, unsigned short port_number);
extern struct in_addr extract_v4_addr(const struct sockaddr_storage *ss);

/**
 * Functions to support listening sockets.
 */
/** How many pending connections queue of a listening server will hold. */
#define BACKLOG	10
extern int para_listen(unsigned l3type, unsigned l4type, unsigned short port);

/** Pretty-printing of IPv4/6 socket addresses */
extern char *local_name(int sockfd);
extern char *remote_name(int sockfd);

/** used to crypt the communication between para_server and para_client */
typedef void crypt_function(unsigned long len,
	const unsigned char *indata, unsigned char *outdata, void *private_data);

int send_buffer(int, const char *);
int send_bin_buffer(int, const char *, size_t);
__printf_2_3 int send_va_buffer(int fd, const char *fmt, ...);
int recv_buffer(int fd, char *buf, size_t size);
int recv_bin_buffer(int fd, char *buf, size_t size);
int para_accept(int, void *addr, socklen_t size);
int create_local_socket(const char *name, struct sockaddr_un *unix_addr,
	mode_t mode);
int create_remote_socket(const char *name);
int recv_cred_buffer(int, char *, size_t);
ssize_t send_cred_buffer(int, char*);
int recv_pattern(int fd, const char *pattern, size_t bufsize);
void enable_crypt(int fd, crypt_function *recv_f, crypt_function *send_f,
	void *private_data);
void disable_crypt(int fd);
